@@ -7,7 +7,7 @@ use base qw( Exporter );
 
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 # This method carries out the actual package variable inheritance via export
@@ -52,11 +52,11 @@ sub inherit {
 # Make a static field inheritable by adding it to @EXPORT_INHERIT
 sub pkg_inheritable {
     my ($callpkg, $symbol, $value) = @_;
-    ref $callpkg and croak "pkg_inheritable: called on a reference: $callpkg\n";
+    ref $callpkg and croak "pkg_inheritable: called on a reference: $callpkg";
 
     no strict "refs";
     my $export_ok = \@{"${callpkg}::EXPORT_INHERIT"};
-    croak "pkg_inheritable: trying to redefine symbol 'symbol'\n"
+    croak "pkg_inheritable: trying to redefine symbol '$symbol' in package $callpkg"
         if grep { $_ eq $symbol } @$export_ok;
 
     $symbol =~ s/^(\W)// or croak "pkg_inheritable: no sigil in symbol '$symbol'";
@@ -140,7 +140,7 @@ Package::Data::Inheritable - Inheritable and overridable package data/variables
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -148,13 +148,11 @@ Version 0.02
 
 Method interface:
 
-  package Base;
+  package BaseClass;
   use base qw( Package::Data::Inheritable );
 
   BEGIN {
-      inherit Package::Data::Inheritable;
-
-      Base->pkg_inheritable('$class_scalar' => 'a not so ordinary package variable');
+      BaseClass->pkg_inheritable('$class_scalar' => 'a not so ordinary package variable');
   };
 
   print $class_scalar;
@@ -162,22 +160,25 @@ Method interface:
 Exporter like interface:
 
   package Derived;
-  use base qw( Base );
+  use base qw( BaseClass );
 
   BEGIN {
       # declare our variables and overrides *before* inheriting
       our @EXPORT_INHERIT = qw( $scalar @array );
 
-      inherit Base;
+      inherit BaseClass;
   }
   our @array = (1,2,3);
   our $scalar;
 
+  print $class_scalar,
+        @array, $scalar;
+
 =head1 DESCRIPTION
 
 This module tries to deliver inheritable package data (variables) with a reasonably
 convenient interface.
-After declaring variables they can be used like ordinary package variables. Most
+After declaration the variables can be used like ordinary package variables. Most
 importantly, these variables can be inherited by derived classes (packages) by
 calling the inherit() method.
 If a derived class doesn't call inherit() it will still get the ordinary method
@@ -194,8 +195,8 @@ When you assign to an inherited variable within a derived class, every class
 in the inheritance hierarchy will see the new value. If you want to override a
 variable you must redeclare it explicitly.
 
-Two interfaces are provided, one is Exporter like and the other one is based
-on the method pkg_inheritable().
+Two interfaces are provided, one is based on the method pkg_inheritable() and
+the other one is Exporter like.
 The variable visibility (scope) depends on the interface you used. If you use
 the Exporter like interface, variables will be declared via our, while if you
 use the method interface it will be like you had imported those variables.
@@ -214,6 +215,18 @@ much the same way you would set @EXPORT and @EXPORT_OK with Exporter.
 =head1 DEFINING VARIABLES
 
 
+=head2 Method interface
+
+  BEGIN {
+      Class->pkg_inheritable('$scalar');
+      Class->pkg_inheritable('@array' => [1,2,3]);
+  }
+
+Every variable declaration must be inside a BEGIN block because there's no 'our'
+declaration of that variable and we need compile time installation of that
+symbol in the package symbol table.
+
+
 =head2 Exporter like interface
 
   BEGIN {
@@ -230,29 +243,13 @@ The actual our declaration of each variable must be outside the BEGIN block in
 any case because of 'our' scoping rules.
 
 
-=head2 Method interface
-
-  BEGIN {
-      Class->pkg_inheritable('$scalar');
-      Class->pkg_inheritable('@array' => [1,2,3]);
-  }
-
-Every variable declaration must be inside a BEGIN block because there's no 'our'
-declaration of that variable and we need compile time installation of that
-symbol in the package symbol table.
-
-
-
 =head1 OVERRIDING VARIABLES
 
 When you use the Exporter like interface and you want to override a parent
 package variable you must define @EXPORT_INHERIT before calling inherit(),
 otherwise inherit() will not find any of your overrides.
   On the contrary, if you use the pkg_inheritable() method interface, ordering
-doesn't matter. If you define your overrides before calling inherit,
-@EXPORT_INHERIT will already be defined (being set by the method calls).
-If you call inherit and after that you call pkg_inheritable(), this will take
-care of performing the overriding.
+doesn't matter.
 
 
 =head1 METHODS
@@ -304,8 +301,6 @@ on class 'Class'.
     use base qw( Package::Data::Inheritable );
    
     BEGIN {
-        inherit Package::Data::Inheritable;
-   
         Base->pkg_inheritable('$scalar1' => 'Base scalar');
         Base->pkg_inheritable('$scalar2' => 'Base scalar');
         Base->pkg_inheritable('@array'   => [1,2,3]);
@@ -342,31 +337,30 @@ on class 'Class'.
 
 =head2 Accessing and wrapping data members
 
-You are encouraged to properly wrap in accessor/mutator methods your private data.
-Furthermore, be aware that when you qualify your variables with the package
-prefix you're giving up compiler checks on those variables.
+Be aware that when you qualify your variables with the package prefix you're
+giving up compiler checks on those variables.
+Furthermore, access to class data from outside your classes is better avoided.
 
     use strict;
-    package SomeClass;
+    package Base;
     use base qw( Package::Data::Inheritable );
 
     BEGIN {
-        inherit Package::Data::Inheritable;
-
-        __PACKAGE__->pkg_inheritable('$_private_scalar' => 'private scalar');
-        __PACKAGE__->pkg_inheritable('$public_scalar' => 'public scalar');
+        Base->pkg_inheritable('$_some_scalar' => 'some scalar');
+        Base->pkg_inheritable('$public_scalar' => 'public scalar');
     };
 
-    sub new { bless {}, __PACKAGE__ }
+    sub new { bless {}, 'Base' }
 
     # accessor/mutator example
-    sub private_scalar {
-        my ($class, $val) = @_;
-        if (defined $val) {
+    sub some_scalar {
+        my $class = shift;
+        if (@_) {
+           my $val = shift;
            # check $val or croak...
-           $_private_scalar = $val;
+           $_some_scalar = $val;
         }
-        return $_private_scalar;
+        return $_some_scalar;
     }
 
     sub do_something {
@@ -374,31 +368,48 @@ prefix you're giving up compiler checks on those variables.
         # ok
         print $public_scalar;
         # ok, but dangerous
-        print $SomeClass::public_scalar;
+        print $Base::public_scalar;
 
         # compile error
         print $publicscalar;
 
         # variable undefined but no compile error because of package prefix
-        print $SomeClass::publicscalar;
+        print $Base::publicscalar;
     }
 
 
+    package Derived;
+    use base qw( Base );
+    BEGIN {
+        inherit Base;
+    };
+    
+  
+
   And then in some user code:
 
     use strict;
-    use SomeClass;
+    use Base;
+    use Derived;
     
     # prints "public scalar". Discouraged.
-    print $SomeClass::public_scalar;
-    # prints "private scalar"
-    print SomeClass->private_scalar;
+    print $Base::public_scalar;
+    # prints "some scalar"
+    print Base->some_scalar;
     
-    SomeClass->private_scalar("reset!");
-    my $obj = SomeClass->new;
+    Base->some_scalar("reset!");
+    my $obj = Base->new;
     # prints "reset!"
-    print SomeClass->private_scalar;
-    print $obj->private_scalar;
+    print Base->some_scalar;
+    print $obj->some_scalar;
+
+    # prints "reset!"
+    print Derived->some_scalar;
+    Derived->some_scalar("derived reset!");
+    # prints "derived reset!"
+    print Derived->some_scalar;
+    # prints "derived reset!"
+    print Base->some_scalar;
 
 =head1 CAVEATS
 
@@ -461,4 +472,17 @@ under the same terms as Perl itself.
 
 =cut
 
+######################################################
+# TECHNICALITIES
+#
+# - OVERRIDING VARIABLES
+#   When you use the Exporter like interface and you want to override a parent
+#   package variable you must define @EXPORT_INHERIT before calling inherit(),
+#   otherwise inherit() will not find any of your overrides.
+#     On the contrary, if you use the pkg_inheritable() method interface, ordering
+#   doesn't matter. If you define your overrides before calling inherit,
+#   @EXPORT_INHERIT will already be defined (being set by the method calls).
+#   If you call inherit and after that you call pkg_inheritable(), this will take
+#   care of performing the overriding. Do not fit well in the POD but they're still useful
+
 1; # End of Package::Data::Inheritable
